library(testthat)
library(landscapemetrics)
library(terra)

library(dplyr)
library(stringr)
library(tidyr)

test_check("landscapemetrics")
